#
# K2HDKC DBaaS Utilities - Override configuration for K2HDKC DBaaS
#
# Copyright 2021 Yahoo! Japan Corporation.
#
# K2HDKC DBaaS is a DataBase as a Service provided by Yahoo! JAPAN
# which is built K2HR3 as a backend and provides services in
# cooperation with OpenStack.
# The Override configuration for K2HDKC DBaaS serves to connect the
# components that make up the K2HDKC DBaaS. K2HDKC, K2HR3, CHMPX,
# and K2HASH are components provided as AntPickax.
#
# For the full copyright and license information, please view
# the license file that was distributed with this source code.
#
# AUTHOR:   Takeshi Nakatani
# CREATE:   Fri Jan 22 2021
# REVISION:
#

#
# Local macros/define
#
%if %{undefined package_revision}
%global package_revision 1
%endif

%if %{undefined make_build}
%global make_build %{__make} %{?_smp_mflags}
%endif

%if %{undefined autosetup}
%global autosetup %setup -q
%endif

%global gittag v1.0.1

%if %{undefined make_check}
%global make_check 1
%endif

#
# main package
#
Summary: Override configuration for K2HDKC DBaaS
Name: k2hdkc-dbaas-override-conf
Version: 1.0.1
Release: %{package_revision}%{?dist}
License: MIT
Group: Applications/Other
URL: https://github.com/yahoojapan/k2hdkc-dbaas-override-conf
Source0: https://github.com/yahoojapan/k2hdkc-dbaas-override-conf/archive/%{gittag}/%{name}-%{version}.tar.gz
BuildRequires: git-core make
BuildArch: noarch

%description
K2HDKC DBaaS Override Configuration is a setting for
connecting each component running on the Virtual Machine
that enjoys the functions of K2HDKC DBaaS.
This Configuration allows CHMPX and K2HDKC components to
work together and exchange data with K2HR3.
Install the configuration file for linking the systemd
services of CHMPX, K2HDKC, and K2HR3 GET RESOURCE.
This allows these systemd services to act as the
foundation for K2HDKC DBaaS.

%prep
%autosetup -n %{name}-%{version}

%build
./autogen.sh
%configure --disable-static 
%make_build

%install
%make_install
install -D -m 644 src/override.conf %{buildroot}/etc/antpickax/override.conf

%post
if [ "$1" -eq 1 ]; then
    if [ -d /etc/antpickax -a -f /etc/antpickax/k2hr3-api-uri -a -f /etc/antpickax/k2hr3-role-name -a -f /etc/antpickax/k2hr3-role-name -a -f /etc/antpickax/k2hr3-cuk-param ]; then
        K2HR3_URI=$(cat /etc/antpickax/k2hr3-api-uri)
        K2HR3_ROLE=$(cat /etc/antpickax/k2hr3-role-name)
        K2HR3_RESOURCE=$(cat /etc/antpickax/k2hr3-role-name | sed 's/:role:/:resource:/g')
        K2HR3_CUK=$(cat /etc/antpickax/k2hr3-cuk-param)
        K2HDKC_PROC_USER="k2hdkc"
        K2HR3_RESULT=$(curl -s -X GET -H 'Content-Type: application/json' "${K2HR3_URI}"/v1/resource/"${K2HR3_RESOURCE}"?"${K2HR3_CUK}"\&role="${K2HR3_ROLE}"\&type=keys\&keyname=k2hdkc-dbaas-proc-user)
        echo "${K2HR3_RESULT}" | grep -q '"result":true'
        if [ $? -eq 0 ]; then
            K2HDKC_PROC_USER=$(echo "${K2HR3_RESULT}" | sed 's/^.*\"resource\":\"\([^\"]*\)*\".*$/\1/g' | grep -v "[^a-zA-Z0-9_]")
            if [ "X${K2HDKC_PROC_USER}" != "X" ]; then
                sed -i -e "s/chmpx-service-helper.conf:SUBPROCESS_USER[[:space:]]*=.*$/chmpx-service-helper.conf:SUBPROCESS_USER\t\t= ${K2HDKC_PROC_USER}/g" -e "s/k2hdkc-service-helper.conf:SUBPROCESS_USER[[:space:]]*=.*$/k2hdkc-service-helper.conf:SUBPROCESS_USER\t\t= ${K2HDKC_PROC_USER}/g" /etc/antpickax/override.conf
            else
                K2HDKC_PROC_USER="k2hdkc"
            fi
        fi
        K2HR3_RESULT=$(curl -s -X GET -H 'Content-Type: application/json' "${K2HR3_URI}"/v1/resource/"${K2HR3_RESOURCE}"?"${K2HR3_CUK}"\&role="${K2HR3_ROLE}"\&type=keys\&keyname=k2hdkc-dbaas-add-user)
        echo "${K2HR3_RESULT}" | grep -q '"result":true'
        if [ $? -eq 0 ]; then
            K2HDKC_ADD_USER=$(echo "${K2HR3_RESULT}" | sed 's/^.*\"resource\":\(.*\)}.*$/\1/g')
            if [ "X${K2HDKC_ADD_USER}" = "X1" ]; then
                id -u "${K2HDKC_PROC_USER}" >/dev/null 2>&1
                if [ $? -ne 0 ]; then
                    grep -q "^${K2HDKC_PROC_USER}:" /etc/group
                    if [ $? -ne 0 ]; then
                        useradd -s /bin/sh -d /home/"${K2HDKC_PROC_USER}" -m "${K2HDKC_PROC_USER}"
                    else
                        useradd -s /bin/sh -d /home/"${K2HDKC_PROC_USER}" -m "${K2HDKC_PROC_USER}" -g "${K2HDKC_PROC_USER}"
                    fi
                fi
            fi
        fi
    fi
fi

%if %{make_check}
%check
%{__make} check
%endif

%files
%license COPYING
%doc README AUTHORS ChangeLog
/etc/antpickax/*

%changelog
* Fri Mar 12 2021 Takeshi Nakatani <ggtakec@gmail.com>   1.0.1-1
- Added post install process for process execution user - #9

* Fri Feb 05 2021 Takeshi Nakatani <ggtakec@gmail.com>   1.0.0
- Updated README and README.md for stable release - #7

* Wed Feb 03 2021 Takeshi Nakatani <ggtakec@gmail.com>   0.9.3
- Updated override.conf for k2hdkc.service and README.md - #5

* Tue Feb 02 2021 Takeshi Nakatani <ggtakec@gmail.com>   0.9.2
- Updated override.conf file - #3

* Mon Feb 01 2021 Takeshi Nakatani <ggtakec@gmail.com>   0.9.1
- Changed subprocess run user from current to k2hdkc - #1

* Wed Jan 27 2021 Takeshi Nakatani <ggtakec@gmail.com>   0.9.0
- First version
